==> govway-installer-3.3.18.tgz: org/apache/wss4j/dom/transform/AttachmentTransformParameterSpec.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.wss4j.dom.transform;

import org.apache.wss4j.common.ext.Attachment;

import javax.security.auth.callback.CallbackHandler;
import javax.xml.crypto.dsig.spec.TransformParameterSpec;

public class AttachmentTransformParameterSpec implements TransformParameterSpec {

    private CallbackHandler attachmentCallbackHandler;
    private Attachment attachment;
    private boolean explicitInclusiveNS;

    public AttachmentTransformParameterSpec(
            CallbackHandler attachmentCallbackHandler,
            Attachment attachment,
            boolean explicitInclusiveNS) {
        this.attachmentCallbackHandler = attachmentCallbackHandler;
        this.attachment = attachment;
        this.explicitInclusiveNS = explicitInclusiveNS;
    }

    public CallbackHandler getAttachmentCallbackHandler() {
        return attachmentCallbackHandler;
    }

    public Attachment getAttachment() {
        return attachment;
    }
    
    public boolean getExplicitInclusiveNS() {
        return explicitInclusiveNS;
    }
}

==> govway-installer-3.4.1.tgz: org/apache/wss4j/dom/transform/AttachmentTransformParameterSpec.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.wss4j.dom.transform;

import org.apache.wss4j.common.ext.Attachment;

import javax.security.auth.callback.CallbackHandler;
import javax.xml.crypto.dsig.spec.TransformParameterSpec;

public class AttachmentTransformParameterSpec implements TransformParameterSpec {

    private CallbackHandler attachmentCallbackHandler;
    private Attachment attachment;
    private boolean explicitInclusiveNS;

    public AttachmentTransformParameterSpec(
            CallbackHandler attachmentCallbackHandler,
            Attachment attachment,
            boolean explicitInclusiveNS) {
        this.attachmentCallbackHandler = attachmentCallbackHandler;
        this.attachment = attachment;
        this.explicitInclusiveNS = explicitInclusiveNS;
    }

    public CallbackHandler getAttachmentCallbackHandler() {
        return attachmentCallbackHandler;
    }

    public Attachment getAttachment() {
        return attachment;
    }
    
    public boolean isExplicitInclusiveNS() {
        return explicitInclusiveNS;
    }
}
